==> mx-system-sounds_18.11.tar.xz: mx-system-sounds-18.11/translations/mx-system-sounds_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>mxsystemsounds</name>
    <message>
        <location filename="../mxsystemsounds.ui" line="14"/>
        <location filename="../mxsystemsounds.cpp" line="70"/>
        <location filename="../mxsystemsounds.cpp" line="288"/>
        <location filename="../mxsystemsounds.cpp" line="300"/>
        <location filename="../mxsystemsounds.cpp" line="334"/>
        <source>MX System Sounds</source>
        <translation>MX Sonidos del Sistema</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="48"/>
        <source>Event Sounds</source>
        <translation>Sonidos de eventos</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="61"/>
        <source>Session Sounds</source>
        <translation>Sonidos de la sessión</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="68"/>
        <source>XFCE Event Sounds</source>
        <translation>XFCE sonidos de eventos</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="75"/>
        <source>Login</source>
        <translation>Ingreso</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="82"/>
        <source>XFCE Input Feedback Sounds</source>
        <translation>XFCE sonidos de reacción a la entrada</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="89"/>
        <source>Logout</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="118"/>
        <source>Custom Sounds</source>
        <translation>Sonidos personalizados</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="125"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="132"/>
        <location filename="../mxsystemsounds.ui" line="153"/>
        <source>Login Sound</source>
        <translation>Sonido del ingreso</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="139"/>
        <location filename="../mxsystemsounds.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="164"/>
        <location filename="../mxsystemsounds.ui" line="207"/>
        <location filename="../mxsystemsounds.ui" line="210"/>
        <source>Theme Default</source>
        <translation>Tema preseleccionada</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="167"/>
        <source>Use Default</source>
        <translation>Utiliza preseleccionada</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="178"/>
        <location filename="../mxsystemsounds.ui" line="196"/>
        <source>Logout Sound</source>
        <translation>Sonido de salida</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="229"/>
        <source>Borealis</source>
        <translation>Borealis</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="260"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="263"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="270"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="286"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="289"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="296"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="354"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="380"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="383"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="390"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="287"/>
        <source>About MX System Sounds</source>
        <translation>Acerca de MX sonidos del sistema</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="288"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="289"/>
        <source>Configure Event &amp; Session Sounds</source>
        <translation>Configurar sonidos de eventos y sessión</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="291"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="292"/>
        <location filename="../mxsystemsounds.cpp" line="300"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="293"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="294"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="309"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="353"/>
        <location filename="../mxsystemsounds.cpp" line="383"/>
        <source>Select Sound File</source>
        <translation>Seleccione archivo de sonido</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="353"/>
        <location filename="../mxsystemsounds.cpp" line="383"/>
        <source>Sound Files (*.mp3 *.m4a *.aac *.flac *.ogg *.oga *.wav)</source>
        <translation>Archivos de sonidos (*.mp3 *.m4a *.aac *.flac *.ogg *.oga *.wav)</translation>
    </message>
</context>
</TS>

==> mx-system-sounds_19.4.tar.xz: mx-system-sounds-19.4/translations/mx-system-sounds_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>mxsystemsounds</name>
    <message>
        <location filename="../mxsystemsounds.ui" line="14"/>
        <location filename="../mxsystemsounds.cpp" line="70"/>
        <location filename="../mxsystemsounds.cpp" line="288"/>
        <location filename="../mxsystemsounds.cpp" line="300"/>
        <location filename="../mxsystemsounds.cpp" line="334"/>
        <source>MX System Sounds</source>
        <translation>MX Sonidos del Sistema</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="48"/>
        <source>Event Sounds</source>
        <translation>Sonidos de eventos</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="61"/>
        <source>Session Sounds</source>
        <translation>Sonidos de la sessión</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="68"/>
        <source>XFCE Event Sounds</source>
        <translation>XFCE sonidos de eventos</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="75"/>
        <source>Login</source>
        <translation>Ingreso</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="82"/>
        <source>XFCE Input Feedback Sounds</source>
        <translation>XFCE sonidos de reacción a la entrada</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="89"/>
        <source>Logout</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="118"/>
        <source>Custom Sounds</source>
        <translation>Sonidos personalizados</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="125"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="132"/>
        <location filename="../mxsystemsounds.ui" line="153"/>
        <source>Login Sound</source>
        <translation>Sonido del ingreso</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="139"/>
        <location filename="../mxsystemsounds.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="164"/>
        <location filename="../mxsystemsounds.ui" line="207"/>
        <location filename="../mxsystemsounds.ui" line="210"/>
        <source>Theme Default</source>
        <translation>Tema preseleccionado</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="167"/>
        <source>Use Default</source>
        <translation>Utilizar preseleccionados</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="178"/>
        <location filename="../mxsystemsounds.ui" line="196"/>
        <source>Logout Sound</source>
        <translation>Sonido de salida</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="229"/>
        <source>Borealis</source>
        <translation>Borealis</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="260"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="263"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="270"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="286"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="289"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="296"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="354"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="380"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="383"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.ui" line="390"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="287"/>
        <source>About MX System Sounds</source>
        <translation>Acerca de MX sonidos del sistema</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="288"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="289"/>
        <source>Configure Event &amp; Session Sounds</source>
        <translation>Configurar sonidos de eventos y sessión</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="291"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="292"/>
        <location filename="../mxsystemsounds.cpp" line="300"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="293"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="294"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="309"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="353"/>
        <location filename="../mxsystemsounds.cpp" line="383"/>
        <source>Select Sound File</source>
        <translation>Seleccione archivo de sonido</translation>
    </message>
    <message>
        <location filename="../mxsystemsounds.cpp" line="353"/>
        <location filename="../mxsystemsounds.cpp" line="383"/>
        <source>Sound Files (*.mp3 *.m4a *.aac *.flac *.ogg *.oga *.wav)</source>
        <translation>Archivos de sonido (*.mp3 *.m4a *.aac *.flac *.ogg *.oga *.wav)</translation>
    </message>
</context>
</TS>
